@@ -53,7 +53,6 @@ struct XfpmBrightnessPrivate
 
   gint32    max_level;
   gint32    current_level;
-  gint32    hw_min_level;
   gint32    min_level;
   gint32    step;
   gfloat    exp_step;
@@ -61,14 +60,15 @@ struct XfpmBrightnessPrivate
 
 G_DEFINE_TYPE_WITH_PRIVATE (XfpmBrightness, xfpm_brightness, G_TYPE_OBJECT)
 
-gboolean
-xfpm_brightness_increase (XfpmBrightness *brightness)
+/**
+ * Returns the next increment in screen brightness, given the current level. If
+ * the increment would be above the maximum brightness, the maximum brightness
+ * is returned.
+ */
+gint32
+xfpm_brightness_inc (XfpmBrightness *brightness, gint32 level)
 {
-  gint32 level, new_level;
-
-  if (!xfpm_brightness_get_level (brightness, &level))
-    return FALSE;
-
+  gint32 new_level;
   if ( brightness->priv->use_exp_step )
   {
     new_level = roundf (level * brightness->priv->exp_step);
@@ -79,17 +79,20 @@ xfpm_brightness_increase (XfpmBrightness *brightness)
     new_level = level + brightness->priv->step;
   }
 
-  return xfpm_brightness_set_level (brightness, new_level);
+  return MIN (xfpm_brightness_get_max_level (brightness), new_level);
 }
 
-gboolean
-xfpm_brightness_decrease (XfpmBrightness *brightness)
+/**
+ * Returns the next decrement in screen brightness, given the current level. If
+ * the decrement would be below 0, then 0 is returned instead. Note that it is
+ * left to callers to define their own lower limits; for an example, see
+ * decrease_brightness in power-manager-button, which clamps the value above 0
+ * to avoid errant mouse scroll events from blanking the display panel entirely.
+ */
+gint32
+xfpm_brightness_dec (XfpmBrightness *brightness, gint32 level)
 {
-  gint32 level, new_level;
-
-  if (!xfpm_brightness_get_level (brightness, &level))
-    return FALSE;
-
+  gint32 new_level;
   if (brightness->priv->use_exp_step)
   {
     new_level = roundf (level / brightness->priv->exp_step);
@@ -100,7 +103,7 @@ xfpm_brightness_decrease (XfpmBrightness *brightness)
     new_level = level - brightness->priv->step;
   }
 
-  return xfpm_brightness_set_level (brightness, new_level);
+  return MAX (0, new_level);
 }
 
 static gboolean
@@ -237,7 +240,7 @@ xfpm_brightness_setup_xrandr (XfpmBrightness *brightness)
 
   if (brightness->priv->backlight == None)
   {
-    XFPM_DEBUG ("No outputs have backlight property");
+    g_warning ("No outputs have backlight property");
     return FALSE;
   }
 
@@ -292,21 +295,29 @@ xfpm_brightness_setup_xrandr (XfpmBrightness *brightness)
 static gint
 xfpm_brightness_helper_get_value (const gchar *argument)
 {
+  gboolean ret;
   GError *error = NULL;
   gchar *stdout_data = NULL;
-  gint status;
+  gint exit_status = 0;
   gint value = -1;
-  gchar *command = g_strdup_printf (SBINDIR "/xfpm-power-backlight-helper --%s", argument);
+  gchar *command = NULL;
 
-  XFPM_DEBUG ("Executing command: %s", command);
-  if (!g_spawn_command_line_sync (command, &stdout_data, NULL, &status, &error)
-      || !g_spawn_check_exit_status (status, &error))
+  command = g_strdup_printf (SBINDIR "/xfpm-power-backlight-helper --%s", argument);
+  ret = g_spawn_command_line_sync (command,
+                                   &stdout_data, NULL, &exit_status, &error);
+  if ( !ret )
   {
-    XFPM_DEBUG ("Failed to get value: %s", error->message);
-    g_error_free (error);
-    g_free (command);
-    return value;
+    if (error)
+    {
+      g_warning ("failed to get value: %s", error->message);
+      g_error_free (error);
+    }
+    goto out;
   }
+  g_debug ("executed %s; retval: %i", command, exit_status);
+
+  if ( exit_status != 0 )
+    goto out;
 
 #if !defined(BACKEND_TYPE_FREEBSD)
   if ( stdout_data[0] == 'N' )
@@ -319,6 +330,7 @@ xfpm_brightness_helper_get_value (const gchar *argument)
   value = atoi (stdout_data);
 #endif
 
+out:
   g_free (command);
   g_free (stdout_data);
   return value;
@@ -330,7 +342,7 @@ xfpm_brightness_setup_helper (XfpmBrightness *brightness)
   gint32 ret;
 
   ret = (gint32) xfpm_brightness_helper_get_value ("get-max-brightness");
-  XFPM_DEBUG ("xfpm_brightness_setup_helper: get-max-brightness returned %i", ret);
+  g_debug ("xfpm_brightness_setup_helper: get-max-brightness returned %i", ret);
   if ( ret < 0 )
   {
     brightness->priv->helper_has_hw = FALSE;
@@ -357,7 +369,7 @@ xfpm_brightness_helper_get_level (XfpmBrightness *brg, gint32 *level)
 
   ret = (gint32) xfpm_brightness_helper_get_value ("get-brightness");
 
-  XFPM_DEBUG ("xfpm_brightness_helper_get_level: get-brightness returned %i", ret);
+  g_debug ("xfpm_brightness_helper_get_level: get-brightness returned %i", ret);
 
   if ( ret >= 0 )
   {
@@ -371,22 +383,28 @@ xfpm_brightness_helper_get_level (XfpmBrightness *brg, gint32 *level)
 static gboolean
 xfpm_brightness_helper_set_level (XfpmBrightness *brg, gint32 level)
 {
+  gboolean ret;
   GError *error = NULL;
-  gint status;
-  gchar *command = g_strdup_printf ("pkexec " SBINDIR "/xfpm-power-backlight-helper --set-brightness %i", level);
+  gint exit_status = 0;
+  gchar *command = NULL;
 
-  XFPM_DEBUG ("Executing command: %s", command);
-  if (!g_spawn_command_line_sync (command, NULL, NULL, &status, &error)
-      || !g_spawn_check_exit_status (status, &error))
+  command = g_strdup_printf ("pkexec " SBINDIR "/xfpm-power-backlight-helper --set-brightness %i", level);
+  ret = g_spawn_command_line_sync (command, NULL, NULL, &exit_status, &error);
+  if ( !ret )
   {
-    XFPM_DEBUG ("Failed to set value: %s", error->message);
-    g_error_free (error);
-    g_free (command);
-    return FALSE;
+    if (error)
+    {
+      g_warning ("xfpm_brightness_helper_set_level: failed to set value: %s", error->message);
+      g_error_free (error);
+    }
+    goto out;
   }
+  g_debug ("executed %s; retval: %i", command, exit_status);
+  ret = (exit_status == 0);
 
+out:
   g_free (command);
-  return TRUE;
+  return ret;
 }
 
 static gboolean
@@ -408,22 +426,28 @@ xfpm_brightness_helper_get_switch (XfpmBrightness *brg, gint *brightness_switch)
 static gboolean
 xfpm_brightness_helper_set_switch (XfpmBrightness *brg, gint brightness_switch)
 {
+  gboolean ret;
   GError *error = NULL;
-  gint status;
-  gchar *command = g_strdup_printf ("pkexec " SBINDIR "/xfpm-power-backlight-helper --set-brightness-switch %i", brightness_switch);
+  gint exit_status = 0;
+  gchar *command = NULL;
 
-  XFPM_DEBUG ("Executing command: %s", command);
-  if (!g_spawn_command_line_sync (command, NULL, NULL, &status, &error)
-      || !g_spawn_check_exit_status (status, &error))
+  command = g_strdup_printf ("pkexec " SBINDIR "/xfpm-power-backlight-helper --set-brightness-switch %i", brightness_switch);
+  ret = g_spawn_command_line_sync (command, NULL, NULL, &exit_status, &error);
+  if ( !ret )
   {
-    XFPM_DEBUG ("Failed to set brightness switch value: %s", error->message);
-    g_error_free (error);
-    g_free (command);
-    return FALSE;
+    if (error)
+    {
+      g_warning ("xfpm_brightness_helper_set_switch: failed to set value: %s", error->message);
+      g_error_free (error);
+    }
+    goto out;
   }
+  g_debug ("executed %s; retval: %i", command, exit_status);
+  ret = (exit_status == 0);
 
+out:
   g_free (command);
-  return TRUE;
+  return ret;
 }
 
 #endif
@@ -472,7 +496,15 @@ xfpm_brightness_finalize (GObject *object)
   G_OBJECT_CLASS (xfpm_brightness_parent_class)->finalize (object);
 }
 
-static gboolean
+XfpmBrightness *
+xfpm_brightness_new (void)
+{
+  XfpmBrightness *brightness = NULL;
+  brightness = g_object_new (XFPM_TYPE_BRIGHTNESS, NULL);
+  return brightness;
+}
+
+gboolean
 xfpm_brightness_setup (XfpmBrightness *brightness)
 {
   xfpm_brightness_free_data (brightness);
@@ -484,9 +516,9 @@ xfpm_brightness_setup (XfpmBrightness *brightness)
                                      brightness->priv->output,
                                      &brightness->priv->min_level,
                                      &brightness->priv->max_level);
-    XFPM_DEBUG ("Brightness controlled by xrandr, min_level=%d max_level=%d",
-                brightness->priv->min_level,
-                brightness->priv->max_level);
+    g_debug ("Brightness controlled by xrandr, min_level=%d max_level=%d",
+             brightness->priv->min_level,
+             brightness->priv->max_level);
 
     return TRUE;
   }
@@ -495,74 +527,23 @@ xfpm_brightness_setup (XfpmBrightness *brightness)
   {
     if ( xfpm_brightness_setup_helper (brightness) ) {
 #if defined(BACKEND_TYPE_FREEBSD)
-      XFPM_DEBUG ("xrandr not available, brightness controlled by sysctl helper; min_level=%d max_level=%d",
+      g_debug ("xrandr not available, brightness controlled by sysctl helper; min_level=%d max_level=%d",
 #else
-      XFPM_DEBUG ("xrandr not available, brightness controlled by sysfs helper; min_level=%d max_level=%d",
+      g_debug ("xrandr not available, brightness controlled by sysfs helper; min_level=%d max_level=%d",
 #endif
-                  brightness->priv->min_level,
-                  brightness->priv->max_level);
+               brightness->priv->min_level,
+               brightness->priv->max_level);
       return TRUE;
     }
   }
 #endif
-  XFPM_DEBUG ("no brightness controls available");
+  g_debug ("no brightness controls available");
   return FALSE;
 }
 
-XfpmBrightness *
-xfpm_brightness_new (void)
+gboolean xfpm_brightness_has_hw (XfpmBrightness *brightness)
 {
-  XfpmBrightness *brightness = g_object_new (XFPM_TYPE_BRIGHTNESS, NULL);
-  if (!xfpm_brightness_setup (brightness))
-  {
-    g_object_unref (brightness);
-    return NULL;
-  }
-
-  brightness->priv->hw_min_level = brightness->priv->min_level;
-
-  return brightness;
-}
-
-gint32 xfpm_brightness_get_min_level (XfpmBrightness *brightness)
-{
-  return brightness->priv->min_level;
-}
-
-/*
- * Some laptops (and mostly newer ones with intel graphics) can turn off the
- * backlight completely. If the user is not careful and sets the brightness
- * very low using the slider, he might not be able to see the screen contents
- * anymore. Brightness keys do not work on every laptop, so it's better to use
- * a safe default minimum level that the user can change via the settings
- * editor if desired.
- */
-void
-xfpm_brightness_set_min_level (XfpmBrightness *brightness,
-                               gint32 level)
-{
-  gint32 max_min = brightness->priv->max_level - brightness->priv->step;
-
-  /* -1 = auto, we set the minimum as 10% of delta */
-  if (level == -1)
-  {
-    brightness->priv->min_level = brightness->priv->hw_min_level
-      + MAX (brightness->priv->step, (brightness->priv->max_level - brightness->priv->hw_min_level) / 10);
-    XFPM_DEBUG ("Setting default min brightness (%d) above hardware min (%d)",
-                brightness->priv->min_level, brightness->priv->hw_min_level);
-    return;
-  }
-
-  if (level < brightness->priv->hw_min_level || level > max_min)
-  {
-    XFPM_DEBUG ("Set min brightness (%d) clamped to admissible values [%d, %d]",
-                level, brightness->priv->hw_min_level, max_min);
-    brightness->priv->min_level = CLAMP (level, brightness->priv->hw_min_level, max_min);
-    return;
-  }
-
-  XFPM_DEBUG ("Setting min brightness at %d", level);
-  brightness->priv->min_level = level;
+  return brightness->priv->xrandr_has_hw || brightness->priv->helper_has_hw;
 }
 
 gint32 xfpm_brightness_get_max_level (XfpmBrightness *brightness)
@@ -588,12 +569,8 @@ gboolean xfpm_brightness_set_level (XfpmBrightness *brightness, gint32 level)
 {
   gboolean ret = FALSE;
 
-  if (level < brightness->priv->min_level || level > brightness->priv->max_level)
-  {
-    XFPM_DEBUG ("Set brightness (%d) clamped to admissible values [%d, %d]",
-                level, brightness->priv->min_level, brightness->priv->max_level);
-    level = CLAMP (level, brightness->priv->min_level, brightness->priv->max_level);
-  }
+  if ( level < brightness->priv->min_level || level > brightness->priv->max_level )
+    return ret;
 
   if (brightness->priv->xrandr_has_hw )
     ret = xfpm_brightness_xrandr_set_level (brightness, brightness->priv->output, level);
@@ -605,17 +582,37 @@ gboolean xfpm_brightness_set_level (XfpmBrightness *brightness, gint32 level)
   return ret;
 }
 
-void xfpm_brightness_set_step_count (XfpmBrightness *brightness, guint32 count, gboolean exponential)
+gboolean xfpm_brightness_set_step_count (XfpmBrightness *brightness, guint32 count, gboolean exponential)
 {
-  guint32 delta;
+  gboolean ret = FALSE;
 
-  if (count < 2)
-    count = 2;
+  if ( xfpm_brightness_has_hw (brightness) ) {
+    guint32 delta;
 
-  delta = brightness->priv->max_level - brightness->priv->hw_min_level;
-  brightness->priv->use_exp_step = exponential;
-  brightness->priv->step = (delta < (count * 2)) ? 1 : (delta / count);
-  brightness->priv->exp_step = powf (delta, 1.0 / count);
+    if ( count < 2 )
+      count = 2;
+    delta = brightness->priv->max_level - brightness->priv->min_level;
+    brightness->priv->use_exp_step = exponential;
+    brightness->priv->step = (delta < (count * 2)) ? 1 : (delta / count);
+    brightness->priv->exp_step = powf (delta, 1.0 / count);
+    ret = TRUE;
+  }
+
+  return ret;
+}
+
+gboolean xfpm_brightness_dim_down (XfpmBrightness *brightness)
+{
+  gboolean ret = FALSE;
+
+  if (brightness->priv->xrandr_has_hw )
+    ret = xfpm_brightness_xrandr_set_level (brightness, brightness->priv->output, brightness->priv->min_level);
+#ifdef ENABLE_POLKIT
+  else if ( brightness->priv->helper_has_hw )
+    ret = xfpm_brightness_helper_set_level (brightness, brightness->priv->min_level);
+#endif
+
+  return ret;
 }
 
 gboolean xfpm_brightness_get_switch (XfpmBrightness *brightness, gint *brightness_switch)
