@@ -458,11 +458,11 @@ display_blank_on_battery_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
   if ( lcd_brightness )
   {
     brg = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-battery"));
-    brightness_value = (gint) gtk_range_get_value (GTK_RANGE (brg));
+    brightness_value = MAX (BRIGHTNESS_DISABLED, 10 * (gint) gtk_range_get_value (GTK_RANGE (brg)));
 
     if ( blank_value * 60 <= brightness_value && brightness_value != BRIGHTNESS_DISABLED)
     {
-      gtk_range_set_value (GTK_RANGE (brg), BRIGHTNESS_DISABLED);
+      gtk_range_set_value (GTK_RANGE (brg), 0);
     }
   }
 
@@ -497,11 +497,11 @@ sleep_on_battery_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
   if ( lcd_brightness )
   {
     brg = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-battery"));
-    brightness_value = (gint) gtk_range_get_value (GTK_RANGE (brg));
+    brightness_value = MAX (BRIGHTNESS_DISABLED, 10 * (gint) gtk_range_get_value (GTK_RANGE (brg)));
 
     if ( sleep_value * 60 <= brightness_value && brightness_value != BRIGHTNESS_DISABLED)
     {
-        gtk_range_set_value (GTK_RANGE (brg), BRIGHTNESS_DISABLED);
+        gtk_range_set_value (GTK_RANGE (brg), 0);
     }
   }
 
@@ -554,11 +554,11 @@ display_blank_on_ac_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
   if ( lcd_brightness )
   {
     brg = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-ac"));
-    brightness_value = (gint) gtk_range_get_value (GTK_RANGE (brg));
+    brightness_value = MAX (BRIGHTNESS_DISABLED, 10 * (gint) gtk_range_get_value (GTK_RANGE (brg)));
 
     if ( blank_value * 60 <= brightness_value && brightness_value != BRIGHTNESS_DISABLED)
     {
-      gtk_range_set_value (GTK_RANGE (brg), BRIGHTNESS_DISABLED);
+      gtk_range_set_value (GTK_RANGE (brg), 0);
     }
   }
 
@@ -598,11 +598,11 @@ sleep_on_ac_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
   {
     brg = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-on-ac"));
 
-    brightness_value = (gint) gtk_range_get_value (GTK_RANGE (brg));
+    brightness_value = MAX (BRIGHTNESS_DISABLED, 10 * (gint) gtk_range_get_value (GTK_RANGE (brg)));
 
     if ( sleep_value * 60 <= brightness_value && brightness_value != BRIGHTNESS_DISABLED)
     {
-      gtk_range_set_value (GTK_RANGE (brg), BRIGHTNESS_DISABLED);
+      gtk_range_set_value (GTK_RANGE (brg), 0);
     }
   }
 
@@ -687,10 +687,23 @@ format_inactivity_value_cb (gint value)
 gchar *
 format_brightness_value_cb (gint value)
 {
-  if ( value <= 9 )
+  gint min, sec;
+
+  if ( value < 1 )
     return g_strdup (_("Never"));
 
-  return g_strdup_printf ("%d %s", value, _("seconds"));
+  /* value > 6 */
+  min = value/6;
+  sec = 10*(value%6);
+
+  if ( min == 0 )
+    return g_strdup_printf ("%d %s", sec, _("seconds"));
+  else if ( min == 1 )
+    if ( sec == 0 )      return g_strdup_printf ("%s", _("One minute"));
+    else                 return g_strdup_printf ("%s %d %s", _("One minute"), sec, _("seconds"));
+  else
+    if ( sec == 0 )      return g_strdup_printf ("%d %s", min, _("minutes"));
+    else                 return g_strdup_printf ("%d %s %d %s", min, _("minutes"), sec, _("seconds"));
 }
 
 gchar *
@@ -702,7 +715,7 @@ format_brightness_percentage_cb (gint value)
 void
 brightness_on_battery_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
 {
-  gint value    = (gint)gtk_range_get_value (GTK_RANGE (w));
+  gint value    = MAX (BRIGHTNESS_DISABLED, 10 * (gint)gtk_range_get_value (GTK_RANGE (w)));
   gint dpms_sleep = (gint) gtk_range_get_value (GTK_RANGE (on_battery_dpms_sleep) );
 
   if ( value != BRIGHTNESS_DISABLED )
@@ -724,7 +737,7 @@ brightness_on_battery_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
 void
 brightness_on_ac_value_changed_cb (GtkWidget *w, XfconfChannel *channel)
 {
-  gint value    = (gint)gtk_range_get_value (GTK_RANGE (w));
+  gint value    = MAX (BRIGHTNESS_DISABLED, 10 * (gint)gtk_range_get_value (GTK_RANGE (w)));
   gint dpms_sleep = (gint) gtk_range_get_value (GTK_RANGE (on_ac_dpms_sleep) );
 
   if ( value != BRIGHTNESS_DISABLED )
@@ -765,13 +778,7 @@ on_battery_lid_changed_cb (GtkWidget *w, XfconfChannel *channel)
   {
     g_critical ("Cannot set value for property %s\n", LID_SWITCH_ON_BATTERY_CFG);
   }
-
-  /* Light Locker Integration */
-  if ( light_locker_settings )
-  {
-    xfpm_update_logind_handle_lid_switch (channel);
-  }
-  /* END Light Locker Integration */
+  xfpm_update_logind_handle_lid_switch (channel);
 }
 
 void
@@ -796,13 +803,7 @@ on_ac_lid_changed_cb (GtkWidget *w, XfconfChannel *channel)
   {
     g_critical ("Cannot set value for property %s\n", LID_SWITCH_ON_AC_CFG);
   }
-
-  /* Light Locker Integration */
-  if ( light_locker_settings )
-  {
-    xfpm_update_logind_handle_lid_switch (channel);
-  }
-  /* END Light Locker Integration */
+  xfpm_update_logind_handle_lid_switch (channel);
 }
 
 void
@@ -851,8 +852,14 @@ brightness_exponential_toggled_cb (GtkWidget *w, XfconfChannel *channel)
 void
 lock_screen_toggled_cb (GtkWidget *w, XfconfChannel *channel)
 {
+  XfconfChannel *session_channel = xfconf_channel_get ("xfce4-session");
   gboolean val = (gint) gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w));
 
+  if ( !xfconf_channel_set_bool (session_channel, "/shutdown/LockScreen", val) )
+  {
+    g_critical ("Unable to set value for property %s\n", LOCK_SCREEN_ON_SLEEP);
+  }
+
   if ( !xfconf_channel_set_bool (channel, XFPM_PROPERTIES_PREFIX LOCK_SCREEN_ON_SLEEP, val) )
   {
     g_critical ("Unable to set value for property %s\n", LOCK_SCREEN_ON_SLEEP);
@@ -1047,7 +1054,7 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_suspend,
     gtk_combo_box_set_model (GTK_COMBO_BOX(lid), GTK_TREE_MODEL(list_store));
 
     gtk_list_store_append (list_store, &iter);
-    gtk_list_store_set (list_store, &iter, 0, _("Switch off display"), 1, LID_TRIGGER_NOTHING, -1);
+    gtk_list_store_set (list_store, &iter, 0, _("Switch off display"), 1, LID_TRIGGER_DPMS, -1);
 
     if ( can_suspend && auth_suspend )
     {
@@ -1064,6 +1071,9 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_suspend,
     gtk_list_store_append(list_store, &iter);
     gtk_list_store_set (list_store, &iter, 0, _("Lock screen"), 1, LID_TRIGGER_LOCK_SCREEN, -1);
 
+    gtk_list_store_append(list_store, &iter);
+    gtk_list_store_set (list_store, &iter, 0, _("Do nothing"), 1, LID_TRIGGER_NOTHING, -1);
+
     gtk_combo_box_set_active (GTK_COMBO_BOX (lid), 0);
 
     val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX LID_SWITCH_ON_BATTERY_CFG, LID_TRIGGER_LOCK_SCREEN);
@@ -1095,8 +1105,8 @@ xfpm_settings_on_battery (XfconfChannel *channel, gboolean auth_suspend,
   brg_level = GTK_WIDGET (gtk_builder_get_object (xml ,"brightness-level-on-battery"));
   if ( has_lcd_brightness )
   {
-    val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_ON_BATTERY, 120);
-    gtk_range_set_value (GTK_RANGE(brg), val);
+    val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_ON_BATTERY, 300);
+    gtk_range_set_value (GTK_RANGE(brg), val / 10);
 
     val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_LEVEL_ON_BATTERY, 20);
     gtk_range_set_value (GTK_RANGE (brg_level), val);
@@ -1235,7 +1245,7 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean auth_suspend,
     gtk_combo_box_set_model (GTK_COMBO_BOX(lid), GTK_TREE_MODEL(list_store));
 
     gtk_list_store_append (list_store, &iter);
-    gtk_list_store_set (list_store, &iter, 0, _("Switch off display"), 1, LID_TRIGGER_NOTHING, -1);
+    gtk_list_store_set (list_store, &iter, 0, _("Switch off display"), 1, LID_TRIGGER_DPMS, -1);
 
     if ( can_suspend && auth_suspend )
     {
@@ -1252,6 +1262,9 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean auth_suspend,
     gtk_list_store_append(list_store, &iter);
     gtk_list_store_set (list_store, &iter, 0, _("Lock screen"), 1, LID_TRIGGER_LOCK_SCREEN, -1);
 
+    gtk_list_store_append(list_store, &iter);
+    gtk_list_store_set (list_store, &iter, 0, _("Do nothing"), 1, LID_TRIGGER_NOTHING, -1);
+
     gtk_combo_box_set_active (GTK_COMBO_BOX (lid), 0);
 
     val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX LID_SWITCH_ON_AC_CFG, LID_TRIGGER_LOCK_SCREEN);
@@ -1282,8 +1295,8 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean auth_suspend,
   brg_level = GTK_WIDGET (gtk_builder_get_object (xml ,"brightness-level-on-ac"));
   if ( has_lcd_brightness )
   {
-    val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_ON_AC, 9);
-    gtk_range_set_value (GTK_RANGE(brg), val);
+    val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_ON_AC, BRIGHTNESS_DISABLED);
+    gtk_range_set_value (GTK_RANGE(brg), val / 10);
 
     val = xfconf_channel_get_uint (channel, XFPM_PROPERTIES_PREFIX BRIGHTNESS_LEVEL_ON_AC, 80);
     gtk_range_set_value (GTK_RANGE (brg_level), val);
@@ -1919,7 +1932,7 @@ update_device_info_value_for_name (GtkTreeView *view,
   g_return_if_fail (name != NULL);
   /* Value can be NULL */
 
-  XFPM_DEBUG ("updating  name %s with value %s", name, value);
+  DBG ("updating  name %s with value %s", name, value);
 
   iter = find_device_info_name_in_tree (view, name);
   if (iter == NULL)
@@ -1960,6 +1973,8 @@ update_sideview_icon (UpDevice *device,
 
   list_store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (sideview)));
 
+  TRACE("entering for %s", object_path);
+
   iter = find_device_in_tree (object_path);
 
   /* quit if device doesn't exist in the sidebar */
@@ -1974,11 +1989,8 @@ update_sideview_icon (UpDevice *device,
                 NULL);
 
 
-  if (upower != NULL)
-  {
-    name = get_device_description (upower, device);
-    icon_name = get_device_icon_name (upower, device, FALSE);
-  }
+  name = get_device_description (upower, device);
+  icon_name = get_device_icon_name (upower, device, FALSE);
 
   pix = gtk_icon_theme_load_icon_for_scale (gtk_icon_theme_get_default (),
                                             icon_name,
@@ -2017,12 +2029,14 @@ update_device_details (UpDevice *device)
   GtkTreeIter *sideview_iter;
   gchar *str;
   guint type = 0, tech = 0;
-  gdouble energy_full_design = -1.0, energy_full = -1.0, energy_empty = -1.0, energy_rate = -1.0, voltage = -1.0, percent = -1.0;
+  gdouble energy_full_design = -1.0, energy_full = -1.0, energy_empty = -1.0, voltage = -1.0, percent = -1.0;
   gboolean p_supply = FALSE;
   gchar *model = NULL, *vendor = NULL, *serial = NULL;
   const gchar *battery_type = NULL;
   const gchar *object_path = up_device_get_object_path(device);
 
+  TRACE("entering for %s", object_path);
+
   sideview_iter = find_device_in_tree (object_path);
 
   /* quit if device doesn't exist in the sidebar */
@@ -2056,7 +2070,6 @@ update_device_details (UpDevice *device)
                 "energy-full-design", &energy_full_design,
                 "energy-full", &energy_full,
                 "energy-empty", &energy_empty,
-                "energy-rate", &energy_rate,
                 "voltage", &voltage,
                 "percentage", &percent,
                 NULL);
@@ -2126,16 +2139,6 @@ update_device_details (UpDevice *device)
       g_free (str);
     }
 
-    if (energy_rate > 0)
-    {
-      /* TRANSLATORS: Unit here is Watt*/
-      str = xfpm_info_get_energy_property (energy_rate, _("W"));
-
-      update_device_info_value_for_name (view, list_store, _("Energy rate"), str);
-
-      g_free (str);
-    }
-
     if (voltage > 0)
     {
       /* TRANSLATORS: Unit here is Volt*/
@@ -2180,6 +2183,8 @@ add_device (UpDevice *device)
   guint index;
   static gboolean first_run = TRUE;
 
+  TRACE("entering for %s", object_path);
+
   /* don't add the same device twice */
   device_iter = find_device_in_tree (object_path);
   if (device_iter)
@@ -2264,6 +2269,8 @@ remove_device (const gchar *object_path)
   gulong signal_id;
   UpDevice *device;
 
+  TRACE("entering for %s", object_path);
+
   iter = find_device_in_tree (object_path);
 
   if (iter == NULL)
@@ -2276,14 +2283,11 @@ remove_device (const gchar *object_path)
                       COL_SIDEBAR_BATTERY_DEVICE, &device,
                       -1);
 
-  if (device)
-  {
-    g_signal_handler_disconnect (device, signal_id);
-    g_object_unref (device);
-  }
-
   gtk_list_store_remove (list_store, iter);
 
+  if (device)
+    g_signal_handler_disconnect (device, signal_id);
+
   /* If there are no devices left, hide the devices tab */
   if(!gtk_tree_model_get_iter_first (GTK_TREE_MODEL(list_store), iter))
     gtk_widget_hide (gtk_notebook_get_nth_page (GTK_NOTEBOOK (nt), devices_page_num));
@@ -2330,12 +2334,10 @@ settings_create_devices_list (void)
 {
   upower = up_client_new ();
 
-  if (upower != NULL)
-  {
-    g_signal_connect (upower, "device-added", G_CALLBACK (device_added_cb), NULL);
-    g_signal_connect (upower, "device-removed", G_CALLBACK (device_removed_cb), NULL);
-    add_all_devices ();
-  }
+  g_signal_connect (upower, "device-added", G_CALLBACK (device_added_cb), NULL);
+  g_signal_connect (upower, "device-removed", G_CALLBACK (device_removed_cb), NULL);
+
+  add_all_devices ();
 }
 
 static void
@@ -2366,9 +2368,6 @@ settings_quit (GtkWidget *widget, XfconfChannel *channel)
   g_object_unref (channel);
   xfconf_shutdown ();
   gtk_widget_destroy (widget);
-  if (upower != NULL)
-    g_object_unref (upower);
-
   /* initiate the quit action on the application so it terminates */
   g_action_group_activate_action (G_ACTION_GROUP(app), "quit", NULL);
 }
@@ -2408,6 +2407,7 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
   GtkWidget *plugged_box;
   GtkWidget *viewport;
   GtkWidget *hbox;
+  GtkWidget *frame;
   GtkWidget *switch_widget;
   GtkWidget *stack;
   GtkStyleContext *context;
@@ -2487,7 +2487,7 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
                                    CAIRO_GOBJECT_TYPE_SURFACE, /* COL_SIDEBAR_ICON */
                                    G_TYPE_STRING,   /* COL_SIDEBAR_NAME */
                                    G_TYPE_INT,      /* COL_SIDEBAR_INT */
-                                   G_TYPE_OBJECT,   /* COL_SIDEBAR_BATTERY_DEVICE */
+                                   G_TYPE_POINTER,  /* COL_SIDEBAR_BATTERY_DEVICE */
                                    G_TYPE_STRING,   /* COL_SIDEBAR_OBJECT_PATH */
                                    G_TYPE_ULONG,    /* COL_SIDEBAR_SIGNAL_ID */
                                    G_TYPE_POINTER   /* COL_SIDEBAR_VIEW */
@@ -2573,34 +2573,16 @@ xfpm_settings_dialog_new (XfconfChannel *channel, gboolean auth_suspend,
 
   if ( !has_lcd_brightness )
   {
-    GtkWidget *widget = GTK_WIDGET (gtk_builder_get_object (xml, "label4"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-label"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-label"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-vbox"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-vbox"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "label6"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-label1"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-label1"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-level-vbox1"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-inactivity-vbox1"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys-label"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "hbox4"));
-    gtk_widget_hide (widget);
-    widget = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-step-count-label"));
-    gtk_widget_hide (widget);
+    frame = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-frame"));
+    gtk_widget_hide (frame);
+    frame = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys"));
+    gtk_widget_hide (frame);
+    frame = GTK_WIDGET (gtk_builder_get_object (xml, "handle-brightness-keys-label"));
+    gtk_widget_hide (frame);
+    frame = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-step-count"));
+    gtk_widget_hide (frame);
+    frame = GTK_WIDGET (gtk_builder_get_object (xml, "brightness-exponential"));
+    gtk_widget_hide (frame);
   }
 
   if ( id != 0 )
@@ -2655,14 +2637,14 @@ xfpm_settings_show_device_id (gchar *device_id)
   gtk_widget_show (gtk_notebook_get_nth_page (GTK_NOTEBOOK (nt), devices_page_num));
   gtk_notebook_set_current_page (GTK_NOTEBOOK (nt), devices_page_num);
 
-  XFPM_DEBUG ("device_id %s", device_id);
+  DBG("device_id %s", device_id);
 
   device_iter = find_device_in_tree (device_id);
   if (device_iter)
   {
     GtkTreeSelection *selection;
 
-    XFPM_DEBUG ("device found");
+    DBG("device found");
 
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (sideview));
 
