@@ -74,6 +74,7 @@ struct XfpmBacklightPrivate
 
   NotifyNotification *n;
 
+  gboolean      has_hw;
   gboolean      on_battery;
 
   gint32          last_level;
@@ -118,7 +119,7 @@ xfpm_backlight_dim_brightness (XfpmBacklight *backlight)
 
     if ( !ret )
     {
-      XFPM_DEBUG ("Unable to get current brightness level");
+      g_warning ("Unable to get current brightness level");
       return;
     }
 
@@ -257,6 +258,9 @@ xfpm_backlight_button_pressed_cb (XfpmButton *button, XfpmButtonKey type, XfpmBa
 
   backlight->priv->block = TRUE;
 
+  /* get the current brightness level */
+  ret = xfpm_brightness_get_level (backlight->priv->brightness, &level);
+
   /* optionally, handle updating the level and setting the screen brightness */
   if ( handle_brightness_keys )
   {
@@ -265,36 +269,21 @@ xfpm_backlight_button_pressed_cb (XfpmButton *button, XfpmButtonKey type, XfpmBa
                                     brightness_exponential);
     if ( type == BUTTON_MON_BRIGHTNESS_UP )
     {
-      xfpm_brightness_increase (backlight->priv->brightness);
+      level = xfpm_brightness_inc (backlight->priv->brightness, level);
     }
     else
     {
-      xfpm_brightness_decrease (backlight->priv->brightness);
+      level = xfpm_brightness_dec (backlight->priv->brightness, level);
     }
-  }
 
-  /* get the current brightness level */
-  ret = xfpm_brightness_get_level (backlight->priv->brightness, &level);
+    ret = xfpm_brightness_set_level (backlight->priv->brightness, level);
+  }
 
   /* optionally, show the result in a popup (even if it did not change) */
   if ( ret && show_popup )
     xfpm_backlight_show (backlight, level);
 }
 
-static void
-xfpm_backlight_handle_brightness_keys_changed (XfpmBacklight *backlight)
-{
-  gboolean handle_keys = FALSE;
-
-  g_object_get (G_OBJECT (backlight->priv->conf),
-                HANDLE_BRIGHTNESS_KEYS, &handle_keys,
-                NULL);
-
-  XFPM_DEBUG ("handle_brightness_keys changed to %s", handle_keys ? "TRUE" : "FALSE");
-
-  xfpm_button_set_handle_brightness_keys (backlight->priv->button, handle_keys);
-}
-
 static void
 xfpm_backlight_brightness_on_ac_settings_changed (XfpmBacklight *backlight)
 {
@@ -385,6 +374,7 @@ xfpm_backlight_init (XfpmBacklight *backlight)
   backlight->priv = xfpm_backlight_get_instance_private (backlight);
 
   backlight->priv->brightness = xfpm_brightness_new ();
+  backlight->priv->has_hw     = xfpm_brightness_setup (backlight->priv->brightness);
 
   backlight->priv->notify = NULL;
   backlight->priv->idle   = NULL;
@@ -397,9 +387,14 @@ xfpm_backlight_init (XfpmBacklight *backlight)
   backlight->priv->brightness_exponential = FALSE;
   backlight->priv->brightness_switch_initialized = FALSE;
 
-  if (backlight->priv->brightness != NULL)
+  if ( !backlight->priv->has_hw )
   {
-    gboolean handle_keys;
+    g_object_unref (backlight->priv->brightness);
+    backlight->priv->brightness = NULL;
+  }
+  else
+  {
+    gboolean ret, handle_keys;
 
     backlight->priv->idle   = egg_idletime_new ();
     backlight->priv->conf   = xfpm_xfconf_new ();
@@ -413,7 +408,14 @@ xfpm_backlight_init (XfpmBacklight *backlight)
                             XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH, G_TYPE_INT,
                             G_OBJECT (backlight), BRIGHTNESS_SWITCH);
 
-    xfpm_brightness_get_switch (backlight->priv->brightness, &backlight->priv->brightness_switch);
+    ret = xfpm_brightness_get_switch (backlight->priv->brightness,
+                      &backlight->priv->brightness_switch);
+
+    if (ret)
+      g_object_set (G_OBJECT (backlight),
+                    BRIGHTNESS_SWITCH,
+                    backlight->priv->brightness_switch,
+                    NULL);
     backlight->priv->brightness_switch_initialized = TRUE;
 
     /*
@@ -438,9 +440,9 @@ xfpm_backlight_init (XfpmBacklight *backlight)
     }
     else
     {
-      XFPM_DEBUG ("It seems the kernel brightness switch handling value was "
-                  "not restored properly on exit last time, xfce4-power-manager "
-                  "will try to restore it this time.");
+      g_warning ("It seems the kernel brightness switch handling value was "
+                 "not restored properly on exit last time, xfce4-power-manager "
+                 "will try to restore it this time.");
     }
 
       /* check whether to change the brightness switch */
@@ -452,22 +454,19 @@ xfpm_backlight_init (XfpmBacklight *backlight)
             BRIGHTNESS_SWITCH,
             backlight->priv->brightness_switch,
             NULL);
-    xfpm_button_set_handle_brightness_keys (backlight->priv->button, handle_keys);
-    g_signal_connect_object (backlight->priv->conf, "notify::" HANDLE_BRIGHTNESS_KEYS,
-                             G_CALLBACK (xfpm_backlight_handle_brightness_keys_changed), backlight, G_CONNECT_SWAPPED);
 
-    g_signal_connect_object (backlight->priv->idle, "alarm-expired",
-                             G_CALLBACK (xfpm_backlight_alarm_timeout_cb), backlight, 0);
-    g_signal_connect_object (backlight->priv->idle, "reset",
-                             G_CALLBACK(xfpm_backlight_reset_cb), backlight, 0);
-    g_signal_connect_object (backlight->priv->button, "button-pressed",
-                             G_CALLBACK (xfpm_backlight_button_pressed_cb), backlight, 0);
-    g_signal_connect_object (backlight->priv->conf, "notify::" BRIGHTNESS_ON_AC,
-                             G_CALLBACK (xfpm_backlight_brightness_on_ac_settings_changed), backlight, G_CONNECT_SWAPPED);
-    g_signal_connect_object (backlight->priv->conf, "notify::" BRIGHTNESS_ON_BATTERY,
-                             G_CALLBACK (xfpm_backlight_brightness_on_battery_settings_changed), backlight, G_CONNECT_SWAPPED);
-    g_signal_connect_object (backlight->priv->power, "on-battery-changed",
-                             G_CALLBACK (xfpm_backlight_on_battery_changed_cb), backlight, 0);
+    g_signal_connect (backlight->priv->idle, "alarm-expired",
+                      G_CALLBACK (xfpm_backlight_alarm_timeout_cb), backlight);
+    g_signal_connect (backlight->priv->idle, "reset",
+                      G_CALLBACK(xfpm_backlight_reset_cb), backlight);
+    g_signal_connect (backlight->priv->button, "button-pressed",
+                      G_CALLBACK (xfpm_backlight_button_pressed_cb), backlight);
+    g_signal_connect_swapped (backlight->priv->conf, "notify::" BRIGHTNESS_ON_AC,
+                              G_CALLBACK (xfpm_backlight_brightness_on_ac_settings_changed), backlight);
+    g_signal_connect_swapped (backlight->priv->conf, "notify::" BRIGHTNESS_ON_BATTERY,
+                              G_CALLBACK (xfpm_backlight_brightness_on_battery_settings_changed), backlight);
+    g_signal_connect (backlight->priv->power, "on-battery-changed",
+                      G_CALLBACK (xfpm_backlight_on_battery_changed_cb), backlight);
 
     g_object_get (G_OBJECT (backlight->priv->power),
                   "on-battery", &backlight->priv->on_battery,
@@ -527,11 +526,11 @@ xfpm_backlight_set_property (GObject *object,
       ret = xfpm_brightness_set_switch (backlight->priv->brightness,
                                         backlight->priv->brightness_switch);
       if (!ret)
-          XFPM_DEBUG ("Unable to set the kernel brightness switch parameter to %d.",
-                      backlight->priv->brightness_switch);
+          g_warning ("Unable to set the kernel brightness switch parameter to %d.",
+                     backlight->priv->brightness_switch);
       else
-          XFPM_DEBUG ("Set kernel brightness switch to %d",
-                      backlight->priv->brightness_switch);
+          g_message ("Set kernel brightness switch to %d",
+                     backlight->priv->brightness_switch);
 
       break;
     case PROP_BRIGHTNESS_SWITCH_SAVE:
@@ -571,11 +570,11 @@ xfpm_backlight_finalize (GObject *object)
     if (ret)
     {
       backlight->priv->brightness_switch = backlight->priv->brightness_switch_save;
-      XFPM_DEBUG ("Restored brightness switch value to: %d", backlight->priv->brightness_switch);
+      g_message ("Restored brightness switch value to: %d", backlight->priv->brightness_switch);
     }
     else
-      XFPM_DEBUG ("Unable to restore the kernel brightness switch parameter to its original value, "
-                  "still resetting the saved value.");
+      g_warning ("Unable to restore the kernel brightness switch parameter to its original value, "
+                 "still resetting the saved value.");
     }
     g_object_unref (backlight->priv->conf);
   }
@@ -598,12 +597,12 @@ xfpm_backlight_finalize (GObject *object)
 XfpmBacklight *
 xfpm_backlight_new (void)
 {
-  XfpmBacklight *backlight = g_object_new (XFPM_TYPE_BACKLIGHT, NULL);
-  if (backlight->priv->brightness == NULL)
-  {
-    g_object_unref (backlight);
-    return NULL;
-  }
-
+  XfpmBacklight *backlight = NULL;
+  backlight = g_object_new (XFPM_TYPE_BACKLIGHT, NULL);
   return backlight;
 }
+
+gboolean xfpm_backlight_has_hw (XfpmBacklight *backlight)
+{
+  return backlight->priv->has_hw;
+}
