@@ -187,8 +187,7 @@ xfpm_manager_finalize (GObject *object)
 
   g_object_unref (manager->priv->dpms);
 
-  if (manager->priv->backlight != NULL)
-    g_object_unref (manager->priv->backlight);
+  g_object_unref (manager->priv->backlight);
 
   g_object_unref (manager->priv->kbd_backlight);
 
@@ -304,7 +303,7 @@ xfpm_manager_shutdown (XfpmManager *manager)
 {
   GError *error = NULL;
 
-  if (manager->priv->systemd != NULL)
+  if ( LOGIND_RUNNING () )
     xfpm_systemd_shutdown (manager->priv->systemd, &error );
   else
     xfpm_console_kit_shutdown (manager->priv->console, &error );
@@ -419,7 +418,7 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
   XfpmLidTriggerAction action;
   gboolean on_battery, logind_handle_lid_switch;
 
-  if (manager->priv->systemd != NULL)
+  if ( LOGIND_RUNNING() )
   {
     g_object_get (G_OBJECT (manager->priv->conf),
                   LOGIND_HANDLE_LID_SWITCH, &logind_handle_lid_switch,
@@ -441,7 +440,7 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
   {
     XFPM_DEBUG_ENUM (action, XFPM_TYPE_LID_TRIGGER_ACTION, "LID close event");
 
-    if ( action == LID_TRIGGER_NOTHING )
+    if ( action == LID_TRIGGER_DPMS )
     {
       if ( !xfpm_is_multihead_connected () )
         xfpm_dpms_force_level (manager->priv->dpms, DPMSModeOff);
@@ -459,7 +458,7 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
         }
       }
     }
-    else
+    else if ( action != LID_TRIGGER_NOTHING )
     {
       /*
        * Force sleep here as lid is closed and no point of asking the
@@ -473,7 +472,8 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
   {
     XFPM_DEBUG_ENUM (action, XFPM_TYPE_LID_TRIGGER_ACTION, "LID opened");
 
-    xfpm_dpms_force_level (manager->priv->dpms, DPMSModeOn);
+    if ( action != LID_TRIGGER_NOTHING )
+      xfpm_dpms_force_level (manager->priv->dpms, DPMSModeOn);
   }
 }
 
@@ -531,10 +531,12 @@ xfpm_manager_set_idle_alarm_on_ac (XfpmManager *manager)
                 ON_AC_INACTIVITY_TIMEOUT, &on_ac,
                 NULL);
 
+#ifdef DEBUG
   if ( on_ac == 14 )
-    XFPM_DEBUG ("setting inactivity sleep timeout on ac to never");
+    TRACE ("setting inactivity sleep timeout on ac to never");
   else
-    XFPM_DEBUG ("setting inactivity sleep timeout on ac to %d", on_ac);
+    TRACE ("setting inactivity sleep timeout on ac to %d", on_ac);
+#endif
 
   if ( on_ac == 14 )
   {
@@ -555,10 +557,12 @@ xfpm_manager_set_idle_alarm_on_battery (XfpmManager *manager)
                 ON_BATTERY_INACTIVITY_TIMEOUT, &on_battery,
                 NULL);
 
+#ifdef DEBUG
   if ( on_battery == 14 )
-    XFPM_DEBUG ("setting inactivity sleep timeout on battery to never");
+    TRACE ("setting inactivity sleep timeout on battery to never");
   else
-    XFPM_DEBUG ("setting inactivity sleep timeout on battery to %d", on_battery);
+    TRACE ("setting inactivity sleep timeout on battery to %d", on_battery);
+#endif
 
   if ( on_battery == 14 )
   {
@@ -638,10 +642,10 @@ xfpm_manager_inhibit_sleep_systemd (XfpmManager *manager)
   const char *why = "xfce4-power-manager handles these events";
   const char *mode = "block";
 
-  if (manager->priv->systemd == NULL)
+  if (g_strcmp0(what, "") == 0)
     return -1;
 
-  if (g_strcmp0 (what, "") == 0)
+  if (!(LOGIND_RUNNING()))
     return -1;
 
   XFPM_DEBUG ("Inhibiting systemd sleep: %s", what);
@@ -739,14 +743,6 @@ xfpm_manager_show_tray_menu (GtkStatusIcon *icon, guint button, guint activate_t
   power_manager_button_show_menu (POWER_MANAGER_BUTTON(manager->priv->power_button));
 }
 
-static gboolean
-xfpm_manager_tray_scroll_event (GtkStatusIcon *status_icon,
-                                GdkEvent *event,
-                                XfpmManager *manager)
-{
-  return power_manager_button_scroll_event (manager->priv->power_button, (GdkEventScroll *) event);
-}
-
 static void
 xfpm_manager_show_tray_icon (XfpmManager *manager)
 {
@@ -758,7 +754,7 @@ xfpm_manager_show_tray_icon (XfpmManager *manager)
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   manager->priv->adapter_icon = gtk_status_icon_new ();
-  manager->priv->power_button = g_object_ref_sink (power_manager_button_new ());
+  manager->priv->power_button = power_manager_button_new ();
 G_GNUC_END_IGNORE_DEPRECATIONS
 
   XFPM_DEBUG ("Showing tray icon");
@@ -779,7 +775,6 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 G_GNUC_END_IGNORE_DEPRECATIONS
 
   g_signal_connect (manager->priv->adapter_icon, "popup-menu", G_CALLBACK (xfpm_manager_show_tray_menu), manager);
-  g_signal_connect (manager->priv->adapter_icon, "scroll-event", G_CALLBACK (xfpm_manager_tray_scroll_event), manager);
 }
 
 static void
@@ -796,7 +791,6 @@ G_GNUC_END_IGNORE_DEPRECATIONS
   g_signal_handlers_disconnect_by_func (G_OBJECT(manager->priv->power_button), G_CALLBACK(xfpm_manager_tray_update_tooltip), manager);
   g_signal_handlers_disconnect_by_func (G_OBJECT(manager->priv->power_button), G_CALLBACK(xfpm_manager_tray_update_icon),    manager);
   g_signal_handlers_disconnect_by_func (G_OBJECT(manager->priv->adapter_icon), G_CALLBACK(xfpm_manager_show_tray_menu),      manager);
-  g_signal_handlers_disconnect_by_func (G_OBJECT(manager->priv->adapter_icon), G_CALLBACK(xfpm_manager_tray_scroll_event),   manager);
 
   g_object_unref (manager->priv->power_button);
   g_object_unref (manager->priv->adapter_icon);
@@ -842,8 +836,8 @@ xfpm_manager_new (GDBusConnection *bus, const gchar *client_id)
   }
   else
   {
-    g_signal_connect_object (manager->priv->client, "quit",
-                             G_CALLBACK (xfpm_manager_quit), manager, G_CONNECT_SWAPPED);
+    g_signal_connect_swapped (manager->priv->client, "quit",
+                              G_CALLBACK (xfpm_manager_quit), manager);
   }
 
   xfpm_manager_dbus_class_init (XFPM_MANAGER_GET_CLASS (manager));
@@ -886,27 +880,27 @@ void xfpm_manager_start (XfpmManager *manager)
     g_clear_error (&error);
   }
 
-  g_signal_connect_object (manager->priv->idle, "alarm-expired",
-                           G_CALLBACK (xfpm_manager_alarm_timeout_cb), manager, 0);
-  g_signal_connect_object (manager->priv->conf, "notify::" ON_AC_INACTIVITY_TIMEOUT,
-                           G_CALLBACK (xfpm_manager_set_idle_alarm_on_ac), manager, G_CONNECT_SWAPPED);
-  g_signal_connect_object (manager->priv->conf, "notify::" ON_BATTERY_INACTIVITY_TIMEOUT,
-                           G_CALLBACK (xfpm_manager_set_idle_alarm_on_battery), manager, G_CONNECT_SWAPPED);
-  g_signal_connect_object (manager->priv->conf, "notify::" LOGIND_HANDLE_POWER_KEY,
-                           G_CALLBACK (xfpm_manager_systemd_events_changed), manager, G_CONNECT_SWAPPED);
-  g_signal_connect_object (manager->priv->conf, "notify::" LOGIND_HANDLE_SUSPEND_KEY,
-                           G_CALLBACK (xfpm_manager_systemd_events_changed), manager, G_CONNECT_SWAPPED);
-  g_signal_connect_object (manager->priv->conf, "notify::" LOGIND_HANDLE_HIBERNATE_KEY,
-                           G_CALLBACK (xfpm_manager_systemd_events_changed), manager, G_CONNECT_SWAPPED);
-  g_signal_connect_object (manager->priv->conf, "notify::" LOGIND_HANDLE_LID_SWITCH,
-                           G_CALLBACK (xfpm_manager_systemd_events_changed), manager, G_CONNECT_SWAPPED);
+  g_signal_connect (manager->priv->idle, "alarm-expired",
+                    G_CALLBACK (xfpm_manager_alarm_timeout_cb), manager);
+  g_signal_connect_swapped (manager->priv->conf, "notify::" ON_AC_INACTIVITY_TIMEOUT,
+                            G_CALLBACK (xfpm_manager_set_idle_alarm_on_ac), manager);
+  g_signal_connect_swapped (manager->priv->conf, "notify::" ON_BATTERY_INACTIVITY_TIMEOUT,
+                            G_CALLBACK (xfpm_manager_set_idle_alarm_on_battery), manager);
+  g_signal_connect_swapped (manager->priv->conf, "notify::" LOGIND_HANDLE_POWER_KEY,
+                            G_CALLBACK (xfpm_manager_systemd_events_changed), manager);
+  g_signal_connect_swapped (manager->priv->conf, "notify::" LOGIND_HANDLE_SUSPEND_KEY,
+                            G_CALLBACK (xfpm_manager_systemd_events_changed), manager);
+  g_signal_connect_swapped (manager->priv->conf, "notify::" LOGIND_HANDLE_HIBERNATE_KEY,
+                            G_CALLBACK (xfpm_manager_systemd_events_changed), manager);
+  g_signal_connect_swapped (manager->priv->conf, "notify::" LOGIND_HANDLE_LID_SWITCH,
+                            G_CALLBACK (xfpm_manager_systemd_events_changed), manager);
 
   xfpm_manager_set_idle_alarm (manager);
 
-  g_signal_connect_object (manager->priv->inhibit, "has-inhibit-changed",
-                           G_CALLBACK (xfpm_manager_inhibit_changed_cb), manager, 0);
-  g_signal_connect_object (manager->priv->monitor, "system-bus-connection-changed",
-                           G_CALLBACK (xfpm_manager_system_bus_connection_changed_cb), manager, 0);
+  g_signal_connect (manager->priv->inhibit, "has-inhibit-changed",
+                    G_CALLBACK (xfpm_manager_inhibit_changed_cb), manager);
+  g_signal_connect (manager->priv->monitor, "system-bus-connection-changed",
+                    G_CALLBACK (xfpm_manager_system_bus_connection_changed_cb), manager);
 
   manager->priv->backlight = xfpm_backlight_new ();
 
@@ -914,26 +908,26 @@ void xfpm_manager_start (XfpmManager *manager)
 
   manager->priv->dpms = xfpm_dpms_new ();
 
-  g_signal_connect_object (manager->priv->button, "button_pressed",
-                           G_CALLBACK (xfpm_manager_button_pressed_cb), manager, 0);
+  g_signal_connect (manager->priv->button, "button_pressed",
+                    G_CALLBACK (xfpm_manager_button_pressed_cb), manager);
 
-  g_signal_connect_object (manager->priv->power, "lid-changed",
-                           G_CALLBACK (xfpm_manager_lid_changed_cb), manager, 0);
+  g_signal_connect (manager->priv->power, "lid-changed",
+                    G_CALLBACK (xfpm_manager_lid_changed_cb), manager);
 
-  g_signal_connect_object (manager->priv->power, "on-battery-changed",
-                           G_CALLBACK (xfpm_manager_on_battery_changed_cb), manager, 0);
+  g_signal_connect (manager->priv->power, "on-battery-changed",
+                    G_CALLBACK (xfpm_manager_on_battery_changed_cb), manager);
 
-  g_signal_connect_object (manager->priv->power, "waking-up",
-                           G_CALLBACK (xfpm_manager_reset_sleep_timer), manager, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (manager->priv->power, "waking-up",
+                            G_CALLBACK (xfpm_manager_reset_sleep_timer), manager);
 
-  g_signal_connect_object (manager->priv->power, "sleeping",
-                           G_CALLBACK (xfpm_manager_reset_sleep_timer), manager, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (manager->priv->power, "sleeping",
+                            G_CALLBACK (xfpm_manager_reset_sleep_timer), manager);
 
-  g_signal_connect_object (manager->priv->power, "ask-shutdown",
-                           G_CALLBACK (xfpm_manager_ask_shutdown), manager, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (manager->priv->power, "ask-shutdown",
+                            G_CALLBACK (xfpm_manager_ask_shutdown), manager);
 
-  g_signal_connect_object (manager->priv->power, "shutdown",
-                           G_CALLBACK (xfpm_manager_shutdown), manager, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (manager->priv->power, "shutdown",
+                            G_CALLBACK (xfpm_manager_shutdown), manager);
 
   xfconf_g_property_bind (xfpm_xfconf_get_channel (manager->priv->conf),
                                                    XFPM_PROPERTIES_PREFIX SHOW_TRAY_ICON_CFG,
@@ -965,13 +959,13 @@ GHashTable *xfpm_manager_get_config (XfpmManager *manager)
   gboolean has_power_button = FALSE;
   gboolean has_battery_button = FALSE;
   gboolean has_battery = TRUE;
-  gboolean has_lcd_brightness = manager->priv->backlight != NULL;
+  gboolean has_lcd_brightness = TRUE;
   gboolean can_shutdown = TRUE;
   gboolean has_lid = FALSE;
 
   hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
-  if (manager->priv->systemd != NULL)
+  if ( LOGIND_RUNNING () )
   {
     g_object_get (G_OBJECT (manager->priv->systemd),
                   "can-shutdown", &can_shutdown,
@@ -993,6 +987,8 @@ GHashTable *xfpm_manager_get_config (XfpmManager *manager)
                 NULL);
 
   has_battery = xfpm_power_has_battery (manager->priv->power);
+  has_lcd_brightness = xfpm_backlight_has_hw (manager->priv->backlight);
+
   mapped_buttons = xfpm_button_get_mapped (manager->priv->button);
 
   if ( mapped_buttons & SLEEP_KEY )
@@ -1060,22 +1056,22 @@ xfpm_manager_dbus_init (XfpmManager *manager)
                                     "/org/xfce/PowerManager",
                                     NULL);
 
-  g_signal_connect_object (manager_dbus,
-                           "handle-quit",
-                           G_CALLBACK (xfpm_manager_dbus_quit),
-                           manager, G_CONNECT_SWAPPED);
-  g_signal_connect_object (manager_dbus,
-                           "handle-restart",
-                           G_CALLBACK (xfpm_manager_dbus_restart),
-                           manager, G_CONNECT_SWAPPED);
-  g_signal_connect_object (manager_dbus,
-                           "handle-get-config",
-                           G_CALLBACK (xfpm_manager_dbus_get_config),
-                           manager, G_CONNECT_SWAPPED);
-  g_signal_connect_object (manager_dbus,
-                           "handle-get-info",
-                           G_CALLBACK (xfpm_manager_dbus_get_info),
-                           manager, G_CONNECT_SWAPPED);
+  g_signal_connect_swapped (manager_dbus,
+                            "handle-quit",
+                            G_CALLBACK (xfpm_manager_dbus_quit),
+                            manager);
+  g_signal_connect_swapped (manager_dbus,
+                            "handle-restart",
+                            G_CALLBACK (xfpm_manager_dbus_restart),
+                            manager);
+  g_signal_connect_swapped (manager_dbus,
+                            "handle-get-config",
+                            G_CALLBACK (xfpm_manager_dbus_get_config),
+                            manager);
+  g_signal_connect_swapped (manager_dbus,
+                            "handle-get-info",
+                            G_CALLBACK (xfpm_manager_dbus_get_info),
+                            manager);
 }
 
 static gboolean
@@ -1144,6 +1140,12 @@ xfpm_manager_dbus_get_info (XfpmManager *manager,
                             GDBusMethodInvocation *invocation,
                             gpointer user_data)
 {
-  xfpm_power_manager_complete_get_info (user_data, invocation, PACKAGE, VERSION, "Xfce");
+
+  xfpm_power_manager_complete_get_info (user_data,
+                                        invocation,
+                                        PACKAGE,
+                                        VERSION,
+                                        "Xfce-goodies");
+
   return TRUE;
 }
