@@ -46,6 +46,7 @@ static void xfpm_xfconf_finalize   (GObject *object);
 struct XfpmXfconfPrivate
 {
   XfconfChannel   *channel;
+  XfconfChannel   *session_channel;
   GValue          *values;
 };
 
@@ -92,10 +93,6 @@ enum
   PROP_LOGIND_HANDLE_HIBERNATE_KEY,
   PROP_LOGIND_HANDLE_LID_SWITCH,
   PROP_HEARTBEAT_COMMAND,
-
-  PROP_SHOW_PANEL_LABEL,
-  PROP_SHOW_PRESENTATION_INDICATOR,
-
   N_PROPERTIES
 };
 
@@ -209,6 +206,31 @@ xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
   g_object_set_property (G_OBJECT (conf), property + strlen (XFPM_PROPERTIES_PREFIX), value);
 }
 
+static void
+xfpm_xfsession_property_changed_cb (XfconfChannel *channel, gchar *property,
+         GValue *value, XfpmXfconf *conf)
+{
+  /*FIXME: Set default for this key*/
+  if ( G_VALUE_TYPE(value) == G_TYPE_INVALID )
+    return;
+
+  XFPM_DEBUG ("property %s\n", property);
+
+  if ( g_strcmp0 (property, "/shutdown/LockScreen") != 0)
+    return;
+
+  /* sanity check */
+  if ( !G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) )
+    return;
+
+  XFPM_DEBUG ("Property modified: %s\n", property);
+
+  /* update xfconf which will update xfpm and keep things in sync */
+  xfconf_channel_set_bool (conf->priv->channel,
+                           XFPM_PROPERTIES_PREFIX LOCK_SCREEN_ON_SLEEP,
+                           g_value_get_boolean(value));
+}
+
 static void
 xfpm_xfconf_class_init (XfpmXfconfClass *klass)
 {
@@ -246,8 +268,8 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    g_param_spec_uint (CRITICAL_POWER_LEVEL,
                                                       NULL, NULL,
                                                       1,
-                                                      70,
-                                                      10,
+                                                      20,
+                                                      5,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -370,9 +392,9 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_LID_ACTION_ON_AC,
                                    g_param_spec_uint (LID_SWITCH_ON_AC_CFG,
                                                       NULL, NULL,
+                                                      LID_TRIGGER_DPMS,
                                                       LID_TRIGGER_NOTHING,
                                                       LID_TRIGGER_LOCK_SCREEN,
-                                                      LID_TRIGGER_LOCK_SCREEN,
                                                       G_PARAM_READWRITE));
 
    /**
@@ -406,9 +428,9 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                    PROP_LID_ACTION_ON_BATTERY,
                                    g_param_spec_uint (LID_SWITCH_ON_BATTERY_CFG,
                                                       NULL, NULL,
+                                                      LID_TRIGGER_DPMS,
                                                       LID_TRIGGER_NOTHING,
                                                       LID_TRIGGER_LOCK_SCREEN,
-                                                      LID_TRIGGER_LOCK_SCREEN,
                                                       G_PARAM_READWRITE));
 
   /**
@@ -543,7 +565,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                       NULL, NULL,
                                                       9,
                                                       G_MAXUINT,
-                                                      120,
+                                                      300,
                                                       G_PARAM_READWRITE));
 
 
@@ -620,34 +642,13 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                          NULL, NULL,
                                                          NULL,
                                                          G_PARAM_READWRITE));
-
-  /**
-   * XfpmXfconf::show-panel-label
-   **/
-  g_object_class_install_property (object_class,
-                                   PROP_SHOW_PANEL_LABEL,
-                                   g_param_spec_int (SHOW_PANEL_LABEL,
-                                                     NULL, NULL,
-                                                     PANEL_LABEL_NONE,
-                                                     PANEL_LABEL_PERCENTAGE_AND_TIME,
-                                                     PANEL_LABEL_PERCENTAGE,
-                                                     G_PARAM_READWRITE));
-
-  /**
-   * XfpmXfconf::show-presentation-indicator
-   **/
-  g_object_class_install_property (object_class,
-                                   PROP_SHOW_PRESENTATION_INDICATOR,
-                                   g_param_spec_boolean (SHOW_PRESENTATION_INDICATOR,
-                                                         NULL, NULL,
-                                                         FALSE,
-                                                         G_PARAM_READWRITE));
 }
 
 static void
 xfpm_xfconf_init (XfpmXfconf *conf)
 {
   GError *error = NULL;
+  gboolean lock_screen;
 
   conf->priv = xfpm_xfconf_get_instance_private (conf);
 
@@ -664,8 +665,26 @@ xfpm_xfconf_init (XfpmXfconf *conf)
   else
   {
     conf->priv->channel = xfconf_channel_get (XFPM_CHANNEL);
-    g_signal_connect_object (conf->priv->channel, "property-changed",
-                             G_CALLBACK (xfpm_xfconf_property_changed_cb), conf, 0);
+    conf->priv->session_channel = xfconf_channel_get ("xfce4-session");
+
+    /* if xfce4-session is around, sync to it on startup */
+    if ( xfconf_channel_has_property (conf->priv->session_channel, "/shutdown/LockScreen") )
+    {
+      lock_screen = xfconf_channel_get_bool (conf->priv->session_channel,
+                                             "/shutdown/LockScreen",
+                                             TRUE);
+
+      XFPM_DEBUG("lock screen %s", lock_screen ? "TRUE" : "FALSE");
+
+      g_object_set (G_OBJECT (conf), LOCK_SCREEN_ON_SLEEP, lock_screen, NULL);
+    }
+
+    g_signal_connect (conf->priv->channel, "property-changed",
+                      G_CALLBACK (xfpm_xfconf_property_changed_cb), conf);
+
+    /* watch for session's property change so we can stay in sync */
+    g_signal_connect (conf->priv->session_channel, "property-changed",
+                      G_CALLBACK (xfpm_xfsession_property_changed_cb), conf);
   }
   xfpm_xfconf_load (conf);
 }
